@@ -122,18 +122,21 @@ class AllLayoutsConfigEvents(AllLayoutsConfig):
     """
 
     def __init__(self, *args, **kwargs):
-        super().__init__(self, *args, **kwargs)
+        super().__init__(*args, **kwargs)
         # TODO: Test more events
 
         @libqtile.hook.subscribe.startup
         def _():
             libqtile.qtile.test_data = {
                 "focus_change": 0,
+                "config_name": self.__class__.__name__,
             }
 
         @libqtile.hook.subscribe.focus_change
         def _():
-            libqtile.qtile.test_data["focus_change"] += 1
+            if hasattr(libqtile.qtile, "test_data"):
+                # focus_change can fire before during startup
+                libqtile.qtile.test_data["focus_change"] += 1
 
 
 each_layout_config = pytest.mark.parametrize(
@@ -251,9 +254,11 @@ def test_focus_change_event(manager):
     # In short, this test prevents layouts from influencing each other in
     # unexpected ways.
 
-    assert manager.c.get_test_data()["focus_change"] == 0
+    # Ensure we are in fact using the right layout
+    assert manager.c.get_test_data()["config_name"].lower() == manager.c.layout.info()["name"]
 
     # Spawning a window must fire only 1 focus_change event
+    assert manager.c.get_test_data()["focus_change"] == 0
     one = manager.test_window("one")
     assert manager.c.get_test_data()["focus_change"] == 1
     two = manager.test_window("two")
