@@ -39,12 +39,12 @@ class TileConfig(Config):
         libqtile.config.Group("a"),
         libqtile.config.Group("b"),
         libqtile.config.Group("c"),
-        libqtile.config.Group("d")
+        libqtile.config.Group("d"),
     ]
     layouts = [
         layout.Tile(),
         layout.Tile(master_length=2),
-        layout.Tile(add_on_top=False)
+        layout.Tile(add_on_top=False),
     ]
     floating_layout = libqtile.resources.default_config.floating_layout
     keys = []
@@ -131,12 +131,12 @@ def test_tile_window_focus_cycle(manager):
     manager.test_window("three")
 
     # test preconditions, Tile adds (by default) clients at pos of current
-    assert manager.c.layout.info()['clients'] == ['three', 'two', 'one']
+    assert manager.c.layout.info()["clients"] == ["three", "two", "one"]
     # last added window has focus
     assert_focused(manager, "three")
 
     # assert window focus cycle, according to order in layout
-    assert_focus_path(manager, 'two', 'one', 'float1', 'float2', 'three')
+    assert_focus_path(manager, "two", "one", "float1", "float2", "three")
 
 
 @tile_config
@@ -156,6 +156,34 @@ def test_tile_add_on_top(manager):
     # test second exemple
     assert_focused(manager, "two")
     manager.test_window("four")
-    assert manager.c.layout.info()["clients"] == ['one', 'two', 'four', 'three']
+    assert manager.c.layout.info()["clients"] == ["one", "two", "four", "three"]
     assert manager.c.layout.info()["slave"] == ["two", "four", "three"]
-    assert_focus_path(manager, 'three', 'one', 'two', 'four')
+    assert_focus_path(manager, "three", "one", "two", "four")
+
+
+@tile_config
+def test_tile_min_max_ratios(manager):
+    manager.test_window("one")
+    manager.test_window("two")
+
+    orig_windows = manager.c.windows()
+
+    # Defaul increment is 5% so 20 steps would move by 100%
+    # i.e. past the edge
+    for _ in range(20):
+        manager.c.layout.decrease_ratio()
+
+    # Window should now be 15% of screen width less it's border
+    assert manager.c.windows()[1]["width"] == (800 * 0.15) - 2
+
+    for _ in range(20):
+        manager.c.layout.increase_ratio()
+
+    # Window should now be 85% of screen width less it's border
+    assert manager.c.windows()[1]["width"] == (800 * 0.85) - 2
+
+    # Reset the layout to original settings
+    manager.c.layout.reset()
+
+    # Check the windows match their original sizes
+    assert manager.c.windows() == orig_windows
