@@ -1,7 +1,7 @@
 import cairocffi
 import pytest
 
-from libqtile import images
+from libqtile import bar, images
 from libqtile.widget import Volume
 from test.widgets.conftest import TEST_DIR
 
@@ -14,10 +14,10 @@ def test_images_fail():
 
 def test_images_good(tmpdir, fake_bar, svg_img_as_pypath):
     names = (
-        'audio-volume-high.svg',
-        'audio-volume-low.svg',
-        'audio-volume-medium.svg',
-        'audio-volume-muted.svg',
+        "audio-volume-high.svg",
+        "audio-volume-low.svg",
+        "audio-volume-medium.svg",
+        "audio-volume-muted.svg",
     )
     for name in names:
         target = tmpdir.join(name)
@@ -25,6 +25,8 @@ def test_images_good(tmpdir, fake_bar, svg_img_as_pypath):
 
     vol = Volume(theme_path=str(tmpdir))
     vol.bar = fake_bar
+    vol.length_type = bar.STATIC
+    vol.length = 0
     vol.setup_images()
     assert len(vol.surfaces) == len(names)
     for name, surfpat in vol.surfaces.items():
@@ -35,19 +37,19 @@ def test_emoji():
     vol = Volume(emoji=True)
     vol.volume = -1
     vol._update_drawer()
-    assert vol.text == '\U0001f507'
+    assert vol.text == "\U0001f507"
 
     vol.volume = 29
     vol._update_drawer()
-    assert vol.text == '\U0001f508'
+    assert vol.text == "\U0001f508"
 
     vol.volume = 79
     vol._update_drawer()
-    assert vol.text == '\U0001f509'
+    assert vol.text == "\U0001f509"
 
     vol.volume = 80
     vol._update_drawer()
-    assert vol.text == '\U0001f50a'
+    assert vol.text == "\U0001f50a"
 
 
 def test_text():
@@ -55,8 +57,8 @@ def test_text():
     vol = Volume(fmt=fmt)
     vol.volume = -1
     vol._update_drawer()
-    assert vol.text == 'M'
+    assert vol.text == "M"
 
     vol.volume = 50
     vol._update_drawer()
-    assert vol.text == '50%'
+    assert vol.text == "50%"
